==> spip_4.0.4.orig.tar.xz: ecrire/lang/public_it_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=it_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Home page', # MODIF
	'articles' => 'Articoli',
	'articles_auteur' => 'Articoli di questo autore',
	'articles_populaires' => 'Articoli più letti',
	'articles_rubrique' => 'Articoli di questa rubrica',
	'aucun_article' => 'Non ci sono articoli a questo indirizzo',
	'aucun_auteur' => 'Non ci sono autrici a questo indirizzo',
	'aucun_site' => 'Non ci sono siti a questo indirizzo',
	'aucune_breve' => 'Non ci sono brevi a questo indirizzo',
	'aucune_rubrique' => 'Non ci sono rubriche a questo indirizzo',
	'autres' => 'Altri',
	'autres_breves' => 'Altre brevi',
	'autres_groupes_mots_clefs' => 'Altri gruppi di parole chiave',
	'autres_sites' => 'Altri siti',

	// B
	'bonjour' => 'Salve',

	// C
	'commenter_site' => 'Commenta questo sito',
	'copie_document_impossible' => 'Impossibile copiare il documento',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Ultimo aggiornamento',
	'dernieres_breves' => 'Ultime brevi',
	'derniers_articles' => 'Ultimi articoli',
	'derniers_commentaires' => 'Ultimi commenti',
	'derniers_messages_forum' => 'Ultimi messaggi pubblicati nei forum',

	// E
	'edition_mode_texte' => 'Versione solo testo di',
	'en_reponse' => 'In risposta a:',
	'en_resume' => 'Riassunto',
	'envoyer_message' => 'Invia un messaggio',
	'espace_prive' => 'Area riservata',

	// F
	'formats_acceptes' => 'Formati accettati: @formats@.',

	// H
	'hierarchie_site' => 'Mappa del sito',

	// J
	'jours' => 'giorni',

	// L
	'lien_connecter' => 'Connettersi',

	// M
	'meme_auteur' => 'Della stessa autrice',
	'meme_rubrique' => 'Nella stessa rubrica',
	'memes_auteurs' => 'Delle stesse autrici',
	'message' => 'Messaggio',
	'messages_forum' => 'Messaggi del forum', # MODIF
	'messages_recents' => 'Messaggi più recenti del forum',
	'mots_clefs' => 'Parole chiave',
	'mots_clefs_meme_groupe' => 'Parole chiave nello stesso gruppo',

	// N
	'navigation' => 'Navigazione',
	'nom' => 'Cognome',
	'nouveautes' => 'Le novità',
	'nouveautes_web' => 'Novità sul Web',
	'nouveaux_articles' => 'Nuovi articoli',
	'nouvelles_breves' => 'Nuove brevi',

	// P
	'page_precedente' => 'pagina precedente',
	'page_suivante' => 'pagina successiva',
	'par_auteur' => 'di ',
	'participer_site' => 'È possibile partecipare alla vita di questo sito e proporre degli articoli iscrivendosi qui sotto. Verrà spedito immediatamente un email con il codice di accesso all’area riservata del sito.',
	'plan_site' => 'Mappa del sito',
	'popularite' => 'Popolarità',
	'poster_message' => 'Inviare un messaggio',
	'proposer_site' => 'È possibile proporre un sito da aggiungere a questa rubrica:',

	// R
	'repondre_article' => 'Rispondere all’articolo',
	'repondre_breve' => 'Rispondere a questa breve',
	'resultats_recherche' => 'Risultati della ricerca',
	'retour_debut_forums' => 'Tornare all’inizio dei forum',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubriche',

	// S
	'signatures_petition' => 'Firme',
	'site_realise_avec_spip' => 'Sito realizzato con SPIP',
	'sites_web' => 'Siti Web',
	'sous_rubriques' => 'Sottorubriche',
	'spam' => 'Spam',
	'suite' => 'segue',
	'sur_web' => 'Sul Web',
	'syndiquer_rubrique' => 'Mettere in syndication questa rubrica',
	'syndiquer_site' => 'Mettere in syndication tutto il sito',

	// T
	'texte_lettre_information' => 'Newsletter del sito',
	'texte_lettre_information_2' => 'Questa lettera recensisce gli articoli e le brevi pubblicati a partire dal', # MODIF

	// V
	'ver_imprimer' => 'Versione per la stampa',
	'voir_en_ligne' => 'Vedi on line',
	'voir_squelette' => 'download del modello di questa pagina'
);

==> spip_4.4.7+dfsg.orig.tar.xz: ecrire/lang/public_it_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=it_fem
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Home page', # MODIF
	'articles' => 'Articoli',
	'articles_auteur' => 'Articoli di questo autore',
	'articles_populaires' => 'Articoli più letti',
	'articles_rubrique' => 'Articoli di questa rubrica',
	'aucun_article' => 'Non ci sono articoli a questo indirizzo',
	'aucun_auteur' => 'Non ci sono autrici a questo indirizzo',
	'aucun_site' => 'Non ci sono siti a questo indirizzo',
	'aucune_breve' => 'Non ci sono brevi a questo indirizzo',
	'aucune_rubrique' => 'Non ci sono rubriche a questo indirizzo',
	'autres' => 'Altri',
	'autres_breves' => 'Altre brevi',
	'autres_groupes_mots_clefs' => 'Altri gruppi di parole chiave',
	'autres_sites' => 'Altri siti',

	// B
	'bonjour' => 'Salve',

	// C
	'commenter_site' => 'Commenta questo sito',
	'copie_document_impossible' => 'Impossibile copiare il documento',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Ultimo aggiornamento',
	'dernieres_breves' => 'Ultime brevi',
	'derniers_articles' => 'Ultimi articoli',
	'derniers_commentaires' => 'Ultimi commenti',
	'derniers_messages_forum' => 'Ultimi messaggi pubblicati nei forum',

	// E
	'edition_mode_texte' => 'Versione solo testo di',
	'en_reponse' => 'In risposta a:',
	'en_resume' => 'Riassunto',
	'envoyer_message' => 'Invia un messaggio',
	'espace_prive' => 'Area riservata',

	// F
	'formats_acceptes' => 'Formati accettati: @formats@.',

	// H
	'hierarchie_site' => 'Mappa del sito',

	// J
	'jours' => 'giorni',

	// L
	'lien_connecter' => 'Connettersi',

	// M
	'meme_auteur' => 'Della stessa autrice',
	'meme_rubrique' => 'Nella stessa rubrica',
	'memes_auteurs' => 'Delle stesse autrici',
	'message' => 'Messaggio',
	'messages_forum' => 'Messaggi del forum', # MODIF
	'messages_recents' => 'Messaggi più recenti del forum',
	'mots_clefs' => 'Parole chiave',
	'mots_clefs_meme_groupe' => 'Parole chiave nello stesso gruppo',

	// N
	'navigation' => 'Navigazione',
	'nom' => 'Cognome',
	'nouveautes' => 'Le novità',
	'nouveautes_web' => 'Novità sul Web',
	'nouveaux_articles' => 'Nuovi articoli',
	'nouvelles_breves' => 'Nuove brevi',

	// P
	'page_precedente' => 'pagina precedente',
	'page_suivante' => 'pagina successiva',
	'par_auteur' => 'di ',
	'participer_site' => 'È possibile partecipare alla vita di questo sito e proporre degli articoli iscrivendosi qui sotto. Verrà spedito immediatamente un email con il codice di accesso all’area riservata del sito.',
	'plan_site' => 'Mappa del sito',
	'popularite' => 'Popolarità',
	'poster_message' => 'Inviare un messaggio',
	'proposer_site' => 'È possibile proporre un sito da aggiungere a questa rubrica:',

	// R
	'repondre_article' => 'Rispondere all’articolo',
	'repondre_breve' => 'Rispondere a questa breve',
	'resultats_recherche' => 'Risultati della ricerca',
	'retour_debut_forums' => 'Tornare all’inizio dei forum',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubriche',

	// S
	'signatures_petition' => 'Firme',
	'site_realise_avec_spip' => 'Sito realizzato con SPIP',
	'sites_web' => 'Siti Web',
	'sous_rubriques' => 'Sottorubriche',
	'spam' => 'Spam',
	'suite' => 'segue',
	'sur_web' => 'Sul Web',
	'syndiquer_rubrique' => 'Mettere in syndication questa rubrica',
	'syndiquer_site' => 'Mettere in syndication tutto il sito',

	// T
	'texte_lettre_information' => 'Newsletter del sito',
	'texte_lettre_information_2' => 'Questa lettera recensisce gli articoli e le brevi pubblicati a partire dal', # MODIF

	// V
	'ver_imprimer' => 'Versione per la stampa',
	'voir_en_ligne' => 'Vedi on line',
	'voir_squelette' => 'download del modello di questa pagina',
];
